@@ -218,7 +218,8 @@ test_provider_set_random (TestProvider *provider,
 
 	for (i = 0; i < nb_proposals; i++)
 	{
-		gchar *name = g_strdup_printf ("Proposal %d", i);
+		gchar *padding = g_strnfill ((i * 3) % 10, 'o');
+		gchar *name = g_strdup_printf ("Propo%ssal %d", padding, i);
 
 		proposals = g_list_prepend (proposals,
 					    gtk_source_completion_item_new (name,
@@ -226,6 +227,7 @@ test_provider_set_random (TestProvider *provider,
 									    icon,
 									    NULL));
 
+		g_free (padding);
 		g_free (name);
 	}
 
@@ -337,7 +339,6 @@ create_window (void)
 	GError *error = NULL;
 	GtkWindow *window;
 	GtkSourceView *source_view;
-	GtkSourceBuffer *source_buffer;
 	GtkSourceCompletion *completion;
 	GtkCheckButton *remember_info_visibility;
 	GtkCheckButton *select_on_show;
@@ -372,16 +373,6 @@ create_window (void)
 	nb_fixed_proposals = GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "spinbutton_nb_fixed_proposals"));
 	nb_random_proposals = GTK_SPIN_BUTTON (gtk_builder_get_object (builder, "spinbutton_nb_random_proposals"));
 
-	/* Workaround for https://bugzilla.gnome.org/show_bug.cgi?id=643732:
-	 * "Source view is created with a GtkTextBuffer instead of GtkSourceBuffer"
-	 */
-	source_buffer = gtk_source_buffer_new (NULL);
-
-	gtk_text_view_set_buffer (GTK_TEXT_VIEW (source_view),
-				  GTK_TEXT_BUFFER (source_buffer));
-
-	g_object_unref (source_buffer);
-
 	completion = gtk_source_view_get_completion (source_view);
 
 	g_signal_connect (window,
